# SMLR Project

## Introduction

This is a project of SMLR (Simplex-based Multinomial Logistic Regression) + Penalty. 

## Starter Guidance

### By `pip`

To create a virtual env in your device, use:

```shell
python3 -m venv .venv
```

Then use pip to install:

```shell
pip install -e .
```

### By `uv`

If you have `uv` as your venv tool for Python, just type:

```shell
uv sync
```

### run test_smlr.py

```shell
python3 test_smlr.py
```

## References

[1] S. Fu, P. Chen, Y. Liu, and Z. Ye, “Simplex-based Multinomial Logistic Regression with Diverging Numbers of Categories and Covariates,” STAT SINICA, 2024, doi: 10.5705/ss.202021.0082.

